@@ -16,7 +16,7 @@ use Text::PDF::Utils;
 use Getopt::Std;
 use strict;
 use vars qw(@ISA %sizes @EXPORT $pdf_helv $pdf_helvb $pdf_helvi $pdf_helvbi $VERSION
-            $dots %transformingops);
+            $dots);
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -41,7 +41,6 @@ BEGIN {
         require IO::Scalar;
     }
     $dots = "0 w [.25 1.25] 0 d";
-    %transformingops = map {$_=>1} qw(m l c v y);
 }
 
 
@@ -157,7 +156,6 @@ EOT
     { $font = Font::TTF::Font->open($ARGV[0]) || die "Can't open font file $ARGV[0]"; }
     $pdf->create_file($ARGV[1]);
     process_font($package, $font, $pdf, $root, $maxx, $maxy, "a0", %opt);
-    $package->final();
     $pdf->close_file;
 }
 
@@ -311,10 +309,8 @@ use strict;
                         && ($gcol = sprintf("%.2f %.2f %.2f rg",
                                             hex($1), hex($2), hex($3)));
                 $glyph = $font->{'loca'}{'glyphs'}[$gid];
-                my @parms = ($cids[$gcount + $i], $gid, $glyph, $rev[$gid], $font);
                 if ($glyph && $glyph->{' LEN'} != 0)
                 {
-                    my (@instr, $in);
                     $glyph->read;
                     $xorg = ($glyph->{'xMax'} + $glyph->{'xMin'}) * $tsize / $upem;
                     $xorg = $xcentre - $xorg / 2;
@@ -322,21 +318,6 @@ use strict;
                     $ppage->add(sprintf("%s %.4f %d m %.4f %d l S [] 0 d\n", $dots, $xadv, $ybase + 7, $xadv,$ybase + 57)) if ($xadv < $xcentre + 27);
                     $ppage->add(sprintf("%s %.4f %d m %.4f %d l S [] 0 d\n", $dots, $xorg, $ybase + 7, $xorg, $ybase + 57)) if ($xorg > $xcentre - 27 && $xorg < $xcentre + 27);
                     $ppage->add(sprintf("BT 1 0 0 1 %.4f %.4f Tm /T$id $tsize Tf 100 Tz $gcol <%04X> Tj %s ET\n", $xorg, $yorg, $gid, ($gcol ? "0 g " : "")));
-                    @instr = $package->overlay(@parms);
-                    if (@instr)
-                    {
-                        $ppage->add("q ");
-                        foreach $in (@instr)
-                        {
-                            if (defined $transformingops{$in->[0]})
-                            {
-                                for (my $j = 1; $j < @{$in}; $j++)
-                                { $in->[$j] = $in->[$j] * $tsize / $upem + ($j % 2 ? $xorg : $yorg); }
-                            }
-                            $ppage->add(join(' ', map {sprintf("%.4f", $_)} @{$in}[1..$#{$in}]) . " $in->[0] ");
-                        }
-                        $ppage->add("Q\n");
-                    }
                     unless ($opt{'r'})
                     {
                         $gxorg = ($glyph->{'xMax'} + $glyph->{'xMin'}) * $gsize / $upem / 2;
@@ -346,6 +327,7 @@ use strict;
                         $ppage->add(sprintf("BT 1 0 0 1 %.4f %.4f Tm /T$id $gsize Tf 100 Tz <%04X> Tj ET\n", $gxorg, $gyorg, $gid));
                     }
                 }
+                @parms = ($cids[$gcount + $i], $gid, $glyph, $rev[$gid], $font);
                 @rowt = $package->topdat(@parms);
                 @roww = widths(6, \@rowt);
                 @xorg = ([$xcentre - 26, $xcentre + 24 - $roww[1]],
@@ -492,7 +474,7 @@ use strict;
                 { $ppage->add(sprintf("%.2f %.2f m %s\n", $x, $y, $blob)); }
             } else
             { $ppage->add(sprintf("%.2f %.2f m %s\n", $x, $y, $offblob)); }
-            if ($txt ne '' && ($opt{'h'} & 1) == 0)
+            if ($txt ne '' && $opt{'h'} & 1 == 0)
             {
                 $tw = $pdf_helv->width($txt) * 4.8 + 2;         # 6pt + 2pt margin
                 $tx = $x + ($dirs[$j][0] > 0 ? 0 : -$tw);
@@ -506,23 +488,10 @@ use strict;
                         $tx, $ty, asPDFStr($txt)));
             }
         }
-        if (($opt{'h'} & 2) == 0)
-        {
-            my ($points) = $package->extra_points($font, $gid, $glyph);
 
-            foreach my $p (@{$points})
-            {
-                $x = ($p->[0] - $fxmin) * $optgsize / $upem + 58;
-                $y = ($p->[1] - $fymin) * $optgsize / $upem + 144;
-                $ppage->add(sprintf("%.2f %.2f m %s\n", $x, $y, $bigblob));
-                $ppage->add(sprintf("BT 1 0 0 1 %.2f %.2f Tm 80 Tz /FR 8 Tf %s Tj ET\n",
-                        $x + 3, $y - 3, asPDFStr($p->[2])));
-            }
-        }
         $ppage->{' curstrm'}{'Filter'} = PDFArray(PDFName('FlateDecode'));
         $ppage->ship_out($pdf);
         $ppage->empty;
-        $glyph->empty;
     }
 }
 
@@ -1010,57 +979,3 @@ sub label
     return '';
 }
 
-
-=head2 extra_points
-
-Returns an array of arrays for a list of extra points to display on the glyph page.
-Each sub array consists of [x, y, label]
-
-=cut
-
-sub extra_points
-{
-    my ($class, $font, $gid, $glyph) = @_;
-
-    return [];
-}
-
-=head2 overlay
-
-Returns an array of arrays, each is an operator string followed by the parameters that will precede
-the operator. If the operator is a contour forming op, then the positions will be transformed
-from glyph space for rendering.
-
-=cut
-
-sub overlay
-{
-    my ($class, $cid, $gid, $glyph, $uid, $font) = @_;
-
-    return [];
-}
-
-=head2 final
-
-Called at the very end to tidy things up in the package
-
-=cut
-
-sub final
-{ }
-
-
-=head1 AUTHOR
-
-Martin Hosken L<http://scripts.sil.org/FontUtils>. 
-
-=head1 LICENSING
-
-Copyright (c) 1998-2014, SIL International (http://www.sil.org)
-
-This module is released under the terms of the Artistic License 2.0.
-For details, see the full text of the license in the file LICENSE.
-
-=cut
-
-1;
