@@ -56,18 +56,3 @@ sub ttfdeflang
 
     return $font;
 }
-
-1;
-
-=head1 AUTHOR
-
-Martin Hosken L<Martin_Hosken@sil.org>. 
-
-=head1 LICENSING
-
-Copyright (c) 1998-2013, SIL International (http://www.sil.org)
-
-This module is released under the terms of the Artistic License 2.0.
-For details, see the full text of the license in the file LICENSE.
-
-=cut
