@@ -160,17 +160,13 @@ sub out_classes
 
         $fh->print("cn${name}Dia = (");
         $count = 0; $sep = '';
-        $self->{'hasnclass'}{$l} = 0;
         for ($c = 0; $c < $f->{'maxp'}{'numGlyphs'}; $c++)
         {
             $psname = $f->{'post'}{'VAL'}[$c];
             next if ($psname eq '' || $psname eq '.notdef');
             next if (vec($vecs->{$l}, $c, 1));
-            next if (!(substr($l, 0, 1) eq "_") and vec($vecs->{"_$l"}, $c, 1));
             next if (defined $glyphs->[$c]{'props'}{'GDL_order'} && $glyphs->[$c]{'props'}{'GDL_order'} <= 1);
-            next unless (vec($self->{'ismarks'}, $c, 1));
             $fh->print("$sep$glyphs->[$c]{'name'}");
-            $self->{'hasnclass'}{$l} = 1;
             if (++$count % 8 == 0)
             { $sep = ",\n    "; }
             else
@@ -220,18 +216,10 @@ sub endtable
 
 sub end_gdl
 {
-    my ($self, $fh, $include, $defines) = @_;
-    my ($k, $v);
+    my ($self, $fh, $include) = @_;
 
-    while (($k, $v) = each %$defines)
-    {
-        $fh->print("\n#define $k $v");
-    }
     $fh->print("\n#define MAXGLYPH " . ($self->{'font'}{'maxp'}{'numGlyphs'} - 1) . "\n");
-    foreach (@$include)
-    {
-        $fh->print("\n#include \"$_\"\n");
-    }
+    $fh->print("\n#include \"$include\"\n") if ($include);
 }
 
 sub make_name
@@ -262,7 +250,7 @@ sub make_name
 
 sub make_point
 {
-    my ($self, $p, $glyph, $opts) = @_;
+    my ($self, $p, $glyph) = @_;
 
     if ($p =~ m/^%([a-z0-9]+)_([a-z0-9]+)$/oi)
     {
@@ -277,7 +265,6 @@ sub make_point
         return undef;
     }
 
-    return undef if ($opts->{'-ignoredAPs'} and $opts->{'-ignoredAPs'} =~ m/\b$p\b/);
     return $p;
 }
 
@@ -420,7 +407,7 @@ EOT
     foreach $p (keys %{$lists})
     {
         next if ($p =~ m/^_/o);
-        $fh->print("cTakes${p}Dia c${p}Dia {attach {to = \@1; at = ${p}S; with = ${p}M}; user1 = 1} / ^ _ " . ($self->{'hasnclass'}{$p} ? "opt4(cnTakes${p}Dia) " : "") . "_ {user1 == 0};\n");
+        $fh->print("cTakes${p}Dia c${p}Dia {attach {to = \@1; at = ${p}S; with = ${p}M}; user1 = 1} / ^ _ opt4(cnTakes${p}Dia) _ {user1 == 0};\n");
     }
     $fh->print("endpass;\nendtable;\n");
 }
@@ -432,18 +419,3 @@ sub has
     { return 1 if ($_ == $val); }
     return 0;
 }
-
-1;
-
-=head1 AUTHOR
-
-Martin Hosken L<http://scripts.sil.org/FontUtils>. 
-
-=head1 LICENSING
-
-Copyright (c) 1998-2014, SIL International (http://www.sil.org)
-
-This module is released under the terms of the Artistic License 2.0.
-For details, see the full text of the license in the file LICENSE.
-
-=cut
