@@ -348,18 +348,4 @@ sub error
 
     print " at line " . $xml->current_line . ".\n";
 }
-
-1;
-
-=head1 AUTHOR
-
-Martin Hosken L<http://scripts.sil.org/FontUtils>. 
-
-=head1 LICENSING
-
-Copyright (c) 1998-2014, SIL International (http://www.sil.org)
-
-This module is released under the terms of the Artistic License 2.0.
-For details, see the full text of the license in the file LICENSE.
-
-=cut
\ No newline at end of file
+            
