@@ -1,11 +1,8 @@
 package Font::TTF::Scripts::Name;
 
-use strict;
 require Exporter;
 use Encode;
 
-use vars qw(@ISA @EXPORT @EXPORT_OK);
-
 @ISA = qw(Exporter);
 @EXPORT = qw(ttfname);
 @EXPORT_OK = (@EXPORT);
@@ -18,17 +15,11 @@ sub ttfname
 
     if (defined $opts{'r'})
     {
-        foreach (split(/[\s,]+/, $opts{'r'}))
-        {
-            my ($n1, $n2) = split('\.\.');
-            $n2 = $n1 unless defined $n2;
-            while ($n1 <= $n2)
-            { $name->remove_name($n1++); }
-        }
-        $name->dirty;
+        delete $name->{'strings'}[$opts{'r'}];
+        return $font;
     }
 
-    foreach my $k (qw(n f w))
+    foreach $k (qw(n f))
     {
         $opts{$k} = decode('utf-8', $opts{$k}) if (defined $opts{$k});
     }
@@ -45,16 +36,15 @@ sub ttfname
     {
         ## my ($cmap) = $font->{'cmap'}->read;
         ## @cover = map {[$_->{'Platform'}, $_->{'Encoding'}]} @{$cmap->{'Tables'}};
-        @cover = $name->pe_list();
+    	@cover = $name->pe_list();
         $opts{'l'} ||= 'en-US';
     }
 
     if (defined $opts{'t'})
     {
         $name->set_name($opts{'t'}, $opts{'n'}, $opts{'l'}, @cover);
-        $name->dirty;
     }
-    elsif ($opts{'n'} || $opts{'f'})
+    else
     {
         my ($subfamily) = $opts{'w'} || $name->find_name(2);
         my ($family, $full, $post, $unique, @time);
@@ -104,23 +94,6 @@ sub ttfname
         $name->set_name(16, $family, $opts{'l'}, @cover);
         $name->set_name(17, $subfamily, $opts{'l'}, @cover);
         $name->set_name(18, $full, $opts{'l'}, @cover);
-        $name->dirty;
     }
     return $font;
 }
-
-1;
-
-
-=head1 AUTHOR
-
-Martin Hosken L<http://scripts.sil.org/FontUtils>. 
-
-=head1 LICENSING
-
-Copyright (c) 1998-2014, SIL International (http://www.sil.org)
-
-This module is released under the terms of the Artistic License 2.0.
-For details, see the full text of the license in the file LICENSE.
-
-=cut
